==> apigateway-0.10.0-sources.jar: software/amazon/awscdk/services/apigateway/cloudformation/AccountResourceProps.java <==
package software.amazon.awscdk.services.apigateway.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.6 (build 04cb6bb)", date = "2018-09-27T21:48:24.480Z")
public interface AccountResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::ApiGateway::Account.CloudWatchRoleArn``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html#cfn-apigateway-account-cloudwatchrolearn
     */
    java.lang.Object getCloudWatchRoleArn();
    /**
     * ``AWS::ApiGateway::Account.CloudWatchRoleArn``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html#cfn-apigateway-account-cloudwatchrolearn
     */
    void setCloudWatchRoleArn(final java.lang.String value);
    /**
     * ``AWS::ApiGateway::Account.CloudWatchRoleArn``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html#cfn-apigateway-account-cloudwatchrolearn
     */
    void setCloudWatchRoleArn(final software.amazon.awscdk.CloudFormationToken value);

    /**
     * @return a {@link Builder} of {@link AccountResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link AccountResourceProps}
     */
    final class Builder {
        @javax.annotation.Nullable
        private java.lang.Object _cloudWatchRoleArn;

        /**
         * Sets the value of CloudWatchRoleArn
         * @param value ``AWS::ApiGateway::Account.CloudWatchRoleArn``
         * @return {@code this}
         */
        public Builder withCloudWatchRoleArn(@javax.annotation.Nullable final java.lang.String value) {
            this._cloudWatchRoleArn = value;
            return this;
        }
        /**
         * Sets the value of CloudWatchRoleArn
         * @param value ``AWS::ApiGateway::Account.CloudWatchRoleArn``
         * @return {@code this}
         */
        public Builder withCloudWatchRoleArn(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._cloudWatchRoleArn = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AccountResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public AccountResourceProps build() {
            return new AccountResourceProps() {
                @javax.annotation.Nullable
                private java.lang.Object $cloudWatchRoleArn = _cloudWatchRoleArn;

                @Override
                public java.lang.Object getCloudWatchRoleArn() {
                    return this.$cloudWatchRoleArn;
                }

                @Override
                public void setCloudWatchRoleArn(@javax.annotation.Nullable final java.lang.String value) {
                    this.$cloudWatchRoleArn = value;
                }

                @Override
                public void setCloudWatchRoleArn(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$cloudWatchRoleArn = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.apigateway.cloudformation.AccountResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::ApiGateway::Account.CloudWatchRoleArn``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html#cfn-apigateway-account-cloudwatchrolearn
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getCloudWatchRoleArn() {
            return this.jsiiGet("cloudWatchRoleArn", java.lang.Object.class);
        }

        /**
         * ``AWS::ApiGateway::Account.CloudWatchRoleArn``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html#cfn-apigateway-account-cloudwatchrolearn
         */
        @Override
        public void setCloudWatchRoleArn(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("cloudWatchRoleArn", value);
        }

        /**
         * ``AWS::ApiGateway::Account.CloudWatchRoleArn``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html#cfn-apigateway-account-cloudwatchrolearn
         */
        @Override
        public void setCloudWatchRoleArn(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("cloudWatchRoleArn", value);
        }
    }
}

==> apigateway-0.11.0-sources.jar: software/amazon/awscdk/services/apigateway/cloudformation/AccountResourceProps.java <==
package software.amazon.awscdk.services.apigateway.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.7 (build b1c202b)", date = "2018-10-11T18:04:28.854Z")
public interface AccountResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::ApiGateway::Account.CloudWatchRoleArn``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html#cfn-apigateway-account-cloudwatchrolearn
     */
    java.lang.Object getCloudWatchRoleArn();
    /**
     * ``AWS::ApiGateway::Account.CloudWatchRoleArn``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html#cfn-apigateway-account-cloudwatchrolearn
     */
    void setCloudWatchRoleArn(final java.lang.String value);
    /**
     * ``AWS::ApiGateway::Account.CloudWatchRoleArn``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html#cfn-apigateway-account-cloudwatchrolearn
     */
    void setCloudWatchRoleArn(final software.amazon.awscdk.Token value);

    /**
     * @return a {@link Builder} of {@link AccountResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link AccountResourceProps}
     */
    final class Builder {
        @javax.annotation.Nullable
        private java.lang.Object _cloudWatchRoleArn;

        /**
         * Sets the value of CloudWatchRoleArn
         * @param value ``AWS::ApiGateway::Account.CloudWatchRoleArn``
         * @return {@code this}
         */
        public Builder withCloudWatchRoleArn(@javax.annotation.Nullable final java.lang.String value) {
            this._cloudWatchRoleArn = value;
            return this;
        }
        /**
         * Sets the value of CloudWatchRoleArn
         * @param value ``AWS::ApiGateway::Account.CloudWatchRoleArn``
         * @return {@code this}
         */
        public Builder withCloudWatchRoleArn(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this._cloudWatchRoleArn = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AccountResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public AccountResourceProps build() {
            return new AccountResourceProps() {
                @javax.annotation.Nullable
                private java.lang.Object $cloudWatchRoleArn = _cloudWatchRoleArn;

                @Override
                public java.lang.Object getCloudWatchRoleArn() {
                    return this.$cloudWatchRoleArn;
                }

                @Override
                public void setCloudWatchRoleArn(@javax.annotation.Nullable final java.lang.String value) {
                    this.$cloudWatchRoleArn = value;
                }

                @Override
                public void setCloudWatchRoleArn(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                    this.$cloudWatchRoleArn = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.apigateway.cloudformation.AccountResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::ApiGateway::Account.CloudWatchRoleArn``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html#cfn-apigateway-account-cloudwatchrolearn
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getCloudWatchRoleArn() {
            return this.jsiiGet("cloudWatchRoleArn", java.lang.Object.class);
        }

        /**
         * ``AWS::ApiGateway::Account.CloudWatchRoleArn``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html#cfn-apigateway-account-cloudwatchrolearn
         */
        @Override
        public void setCloudWatchRoleArn(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("cloudWatchRoleArn", value);
        }

        /**
         * ``AWS::ApiGateway::Account.CloudWatchRoleArn``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-account.html#cfn-apigateway-account-cloudwatchrolearn
         */
        @Override
        public void setCloudWatchRoleArn(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this.jsiiSet("cloudWatchRoleArn", value);
        }
    }
}
